# -*- coding: utf-8 -*-
"""
Created on Wed Feb 28 18:55:58 2018
自定义的一些异常类
@author: 燃烧杯
"""


class CPCAException(Exception):
    pass


class PlaceTypeNotExistException(CPCAException):
    pass


class InputTypeNotSuportException(CPCAException):
    input_type = \
        """
        输入应该为
        |省     |市    |区     |
        |江苏省 |扬州市 |邗江区 |
        格式的pandas.core.frame.DateFrame
        """
    pass



# -*- coding: utf-8 -*-

from codecs import open
from setuptools import setup, find_packages


with open('README.md', 'r', encoding='utf-8') as f:
    readme = f.read()

setup(
    name='addressparser',
    version="0.2.3",
    description='Chinese Address Parser and Extraction Tool,Chinese Province, City and Area Recognition Utilities',
    long_description=readme,
    long_description_content_type='text/markdown',
    author='XuMing',
    author_email='xuming624@qq.com',
    url='https://github.com/shibing624/addressparser',
    license="MIT",
    classifiers=[
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Natural Language :: Chinese (Simplified)',
        'Natural Language :: Chinese (Traditional)',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Topic :: Text Processing',
        'Topic :: Text Processing :: Indexing',
        'Topic :: Text Processing :: Linguistic',
    ],
    keywords='NLP,Simplified Chinese,Chinese geographic information',
    install_requires=[
        "jieba",
        "pandas",
    ],
    packages=find_packages(exclude=['tests']),
    package_dir={'addressparser': 'addressparser'},
    package_data={
        'addressparser': ['*.*'],
    },
    test_suite='tests',
)
